@@ -1,12 +1,13 @@
-#' Get Monte Carlo Node Keys
+#' Extract Key Columns from Monte Carlo Nodes
 #'
-#' Extracts key columns from Monte Carlo node's associated data.
+#' Extracts key columns from a mcnode's associated data.
 #'
-#' @param mcmodule Monte Carlo module containing nodes and data
-#' @param mc_name Name of the node to extract keys from
-#' @param keys_names Vector of column names to extract (optional)
+#' @param mcmodule (mcmodule object). Module containing node.
+#' @param mc_name (character). Node name to extract keys from.
+#' @param keys_names (character vector, optional). Column names to extract.
+#'   If NULL, uses all keys for the node. Default: NULL.
 #'
-#' @return Dataframe with scenario_id and requested key columns
+#' @return A data frame with scenario_id and requested key columns.
 #'
 #' @examples
 #' keys_df <- mc_keys(imports_mcmodule, "w_prev")
@@ -167,18 +168,23 @@ mc_keys <- function(mcmodule, mc_name, keys_names = NULL) {
   data[unique(c("scenario_id", keys_names))]
 }
 
-#' Match Monte Carlo Nodes
+#' Match Two Monte Carlo Nodes
 #'
-#' Matches two mcnodes by:
-#' 1. Group matching - Align nodes with same scenarios but different group order
-#' 2. Scenario matching - Align nodes with same groups but different scenarios
-#' 3. Null matching - Add missing groups across different scenarios
+#' Matches two mcnodes by aligning groups, scenarios, or adding missing
+#' groups across different scenarios.
 #'
-#' @param mcmodule Monte Carlo module
-#' @param mc_name_x First node name
-#' @param mc_name_y Second node name
-#' @param keys_names Names of key columns
-#' @return List containing matched nodes and combined keys (keys_xy)
+#' Matching proceeds in order:
+#' 1. Group matching — align nodes with same scenarios but different group order
+#' 2. Scenario matching — align nodes with same groups but different scenarios
+#' 3. Null matching — add missing groups across different scenarios
+#'
+#' @param mcmodule (mcmodule object). Module containing nodes.
+#' @param mc_name_x (character). First mcnode name.
+#' @param mc_name_y (character). Second mcnode name.
+#' @param keys_names (character vector, optional). Column names for matching.
+#'   Default: NULL.
+#'
+#' @return A list containing matched nodes and combined keys (`keys_xy`).
 #' @examples
 #' test_module <- list(
 #'   node_list = list(
@@ -327,18 +333,18 @@ mc_match <- function(mcmodule, mc_name_x, mc_name_y, keys_names = NULL) {
     keys_y_match[!names(keys_y_match) %in% new_keys],
     keys_y[names(keys_y) %in% new_keys]
   )
-  keys_xy_match <- left_join(
+  keys_xy_match <- dplyr::left_join(
     keys_xy_match,
     keys_x[!names(keys_x) %in% names(keys_xy_match)],
     by = c("g_row.x" = "g_row")
   )
-  keys_xy_match <- left_join(
+  keys_xy_match <- dplyr::left_join(
     keys_xy_match,
     keys_y[!names(keys_y) %in% names(keys_xy_match)],
     by = c("g_row.y" = "g_row")
   )
   keys_xy_match
-  keys_xy <- relocate(
+  keys_xy <- dplyr::relocate(
     keys_xy_match,
     c("g_id", "g_row.x", "g_row.y", "scenario_id")
   )
@@ -411,18 +417,24 @@ mc_match <- function(mcmodule, mc_name_x, mc_name_y, keys_names = NULL) {
   return(result)
 }
 
-#' Match Monte Carlo Node with other data frame
+#' Match Monte Carlo Node with Data Frame
 #'
-#' Matches an mcnode with a data frame by:
-#' 1. Group matching - Same scenarios but different group order
-#' 2. Scenario matching - Same groups but different scenarios
-#' 3. Null matching - Add missing groups across different scenarios
+#' Matches an mcnode with a data frame by aligning groups, scenarios, or adding
+#' missing groups across different scenarios.
 #'
-#' @param mcmodule Monte Carlo module
-#' @param mc_name Node name
-#' @param data Data frame containing keys to match with
-#' @param keys_names Names of key columns
-#' @return List containing matched node, matched data and combined keys (keys_xy
+#' Matching proceeds in order:
+#' 1. Group matching — same scenarios but different group order
+#' 2. Scenario matching — same groups but different scenarios
+#' 3. Null matching — add missing groups across different scenarios
+#'
+#' @param mcmodule (mcmodule object). Module containing node.
+#' @param mc_name (character). Node name.
+#' @param data (data frame). Data to match with mcnode.
+#' @param keys_names (character vector, optional). Column names for matching.
+#'   Default: NULL.
+#'
+#' @return A list containing matched mcnode, matched data, and combined keys
+#'   (`keys_xy`).
 #' @examples
 #' test_data  <- data.frame(pathogen=c("a","b"),
 #'                          inf_dc_min=c(0.05,0.3),
@@ -498,18 +510,18 @@ mc_match_data <- function(mcmodule, mc_name, data, keys_names = NULL) {
     keys_y_match[!names(keys_y_match) %in% new_keys],
     keys_y[names(keys_y) %in% new_keys]
   )
-  keys_xy_match <- left_join(
+  keys_xy_match <- dplyr::left_join(
     keys_xy_match,
     keys_x[!names(keys_x) %in% names(keys_xy_match)],
     by = c("g_row.x" = "g_row")
   )
-  keys_xy_match <- left_join(
+  keys_xy_match <- dplyr::left_join(
     keys_xy_match,
     keys_y[!names(keys_y) %in% names(keys_xy_match)],
     by = c("g_row.y" = "g_row")
   )
   keys_xy_match
-  keys_xy <- relocate(
+  keys_xy <- dplyr::relocate(
     keys_xy_match,
     c("g_id", "g_row.x", "g_row.y", "scenario_id")
   )
@@ -582,16 +594,18 @@ mc_match_data <- function(mcmodule, mc_name, data, keys_names = NULL) {
   return(result)
 }
 
-#' Match Datasets With Differing Scenarios
+#' Match Datasets with Differing Scenarios
 #'
-#' Matches datasets by group and preserves baseline scenarios (scenario_id=0) when scenarios differ between them.
+#' Matches datasets by group and preserves baseline scenarios (scenario_id = 0)
+#' when scenarios differ between them.
 #'
-#' @param x First dataset to match
-#' @param y Second dataset to match
-#' @param by Grouping variable(s) to match on, defaults to NULL
-#' @return List containing matched datasets with aligned scenario IDs:
-#'   - First element: matched version of dataset x
-#'   - Second element: matched version of dataset y
+#' @param x (data frame). First dataset to match.
+#' @param y (data frame). Second dataset to match.
+#' @param by (character vector, optional). Grouping column name(s) to match on.
+#'   If NULL, auto-detected from column names. Default: NULL.
+#'
+#' @return A list containing matched datasets with aligned scenario IDs.
+#'   Element 1: matched version of x. Element 2: matched version of y.
 #' @examples
 #' x <- data.frame(
 #'   category = c("a", "b", "a", "b"),
@@ -653,11 +667,11 @@ wif_match <- function(x, y, by = NULL) {
 
   # Create matched versions of both datasets
   new_x <- x[list_xy$xy$g_row.x, ] %>%
-    mutate(scenario_id = list_xy$xy$scenario_id)
+    dplyr::mutate(scenario_id = list_xy$xy$scenario_id)
   rownames(new_x) <- NULL
 
   new_y <- y[list_xy$xy$g_row.y, ] %>%
-    mutate(scenario_id = list_xy$xy$scenario_id)
+    dplyr::mutate(scenario_id = list_xy$xy$scenario_id)
   rownames(new_y) <- NULL
 
   # Count groups and scenarios for logging
