@@ -175,6 +175,7 @@ suppressMessages({
       data_keys = test_data_keys
     )
 
+    expect_true(node_list$output_2$function_call)
     expect_true(node_list$output_2$na_rm)
     expect_equal(node_list$level$type, c("scalar"))
     expect_equal(node_list$output_3$inputs, c("output_2", "prev_value"))
@@ -223,6 +224,7 @@ suppressMessages({
       data_keys = test_data_keys
     )
 
+    expect_true(node_list$output_2$function_call)
     expect_equal(node_list$output_2$inputs, c("output_1"))
     expect_equal(node_list$output_3$inputs, c("output_2", "prev_value"))
     expect_equal(node_list$output_3$node_exp, c("(1 + output_2) * prev_value"))
@@ -268,4 +270,96 @@ suppressMessages({
 
     expect_equal(sort(node_list2$input_a$keys), sort(c("x", "y")))
   })
+
+  test_that("get_node_list deals with mcdata() and mcstoc() functions", {
+    test_exp1 <- quote({
+      input_b <- mcdata(data=c(0.5, 1.5, 2.5))
+      result <- mcstoc(rnorm, mean= input_b, sd=input_a)
+    })
+
+    test_mctable <- data.frame(
+      mcnode = c("input_a"),
+      mc_func = c("runif"),
+      description = c("Test input A"),
+      stringsAsFactors = FALSE
+    )
+
+    node_list1 <- get_node_list(
+      exp = test_exp1,
+      mctable = test_mctable
+    )
+    
+    expect_true(node_list1$result$function_call)
+    expect_true(node_list1$result$created_in_exp)
+    expect_equal(node_list1$result$inputs, c("input_b","input_a"))
+    expect_equal(node_list1$input_b$type, c("out_node"))
+
+    # Test error when nvariate is provided
+    test_exp2 <- quote({
+      input_b <- mcdata(data=c(0.5, 1.5, 2.5), type = "0", nvariates=3)
+      result <- mcstoc(rnorm, mean= input_b, sd=input_a, type = "V", nvariates=3)
+    })
+
+    expect_error({
+    node_list2 <- get_node_list(
+      exp = test_exp2,
+      mctable = test_mctable
+    )
+    }, "Remove 'nvariates' argument")
+
+  })
+
+  test_that("get_node_list requires a quoted { } expression", {
+    expect_error(
+      get_node_list("not an expression"),
+      "exp must be a quoted expression"
+    )
+    expect_error(
+      get_node_list(123),
+      "exp must be a quoted expression"
+    )
+  })
+
+  test_that("get_node_list warns for unsupported mcnode types (U, VU)", {
+    test_exp_u <- quote({
+      input_b <- mcdata(data = c(0.5, 1.5), type = "U")
+      result <- mcstoc(rnorm, mean = input_b, sd = input_a)
+    })
+
+    test_exp_vu <- quote({
+      input_c <- mcdata(data = c(0.2, 0.8), type = "VU")
+      final <- mcstoc(rnorm, mean = input_c, sd = input_a)
+    })
+
+    test_mctable <- data.frame(
+      mcnode = c("input_a"),
+      mc_func = c("runif"),
+      description = c("Test input A"),
+      stringsAsFactors = FALSE,
+      from_variable = c(NA),
+      transformation = c(NA),
+      sensi_analysis = c(FALSE)
+    )
+
+    expect_warning(
+      node_list_u <- get_node_list(
+        exp = test_exp_u,
+        mctable = test_mctable
+      ),
+      "not fully supported by this mcmodule"
+    )
+    expect_true(node_list_u$result$created_in_exp)
+    expect_true("input_b" %in% names(node_list_u))
+
+    expect_warning(
+      node_list_vu <- get_node_list(
+        exp = test_exp_vu,
+        mctable = test_mctable
+      ),
+      "not fully supported by this mcmodule"
+    )
+    expect_true(node_list_vu$final$created_in_exp)
+    expect_true("input_c" %in% names(node_list_vu))
+  })
+
 })
